@@ -39,6 +39,7 @@ GetOptions(\%OPT, qw(
     missing=s@
     no-decorators|no-header
     no-implications|no-imply
+    precision=i
     prefix=s@
     pretty
     show=s@
@@ -94,12 +95,14 @@ my %CONFIG = (
                : $OPT{format} ? lc $OPT{format}
                : 'yaml',
     'max-batch-size' => $OPT{'max-batch-size'} || 50,
+    precision => $OPT{precision} || 3,
     $OPT{timestamp} ? ( timestamp => $OPT{timestamp} ) : (),
 );
 $OPT{'no-decorators'} = 1 if $CONFIG{format} eq 'json';
 $CONFIG{pretty} = $OPT{pretty} ? 1
                 : $CONFIG{format} =~ /pretty/ ? 1
                 : 0;
+$CONFIG{decimal_format} = "%0.$CONFIG{precision}f";
 #------------------------------------------------------------------------#
 # Handle Indices
 my $ORDER = exists $OPT{asc} && $OPT{asc} ? 'asc' : 'desc';
@@ -268,7 +271,7 @@ if( exists $OPT{top} ) {
     }
 
     my $field = shift @agg_fields;
-    $agg_header = "count\t" . $field;
+    $agg_header = "count\tpct\t" . $field;
     $agg{$top_agg} = { field => $field };
 
     if( $OPT{'bg-filter'} && $top_agg eq 'significant_terms' ) {
@@ -384,7 +387,7 @@ AGES: while( !$DONE && @AGES ) {
     my @always = ();
     push @always, $CONFIG{timestamp} unless $OPT{'no-decorators'};
     if(!$header && @SHOW) {
-        output({color=>'cyan'}, join("\t", @always,@SHOW));
+        output({color=>'cyan'}, join("\t", @always, @SHOW));
         $header++;
     }
 
@@ -411,11 +414,15 @@ AGES: while( !$DONE && @AGES ) {
                         $AGGS_TOTALS{$agg->{key}} ||= 0;
                         $AGGS_TOTALS{$agg->{key}} += $agg->{doc_count};
                         my @out = ();
-
+                        my $top_docs;
                         foreach my $k (qw(score doc_count bg_count key)) {
                             next unless exists $agg->{$k};
                             my $value = delete $agg->{$k};
-                            push @out, defined $value ? ($k eq 'score' ? sprintf "%0.3f", $value : $value ) : '-';
+                            push @out, defined $value ? ($k eq 'score' ? sprintf $CONFIG{decimal_format}, $value : $value ) : '-';
+                            if( $k eq 'doc_count' ) {
+                                push @out, sprintf $CONFIG{decimal_format}, $value ? $value / $result->{hits}{total} : 0;
+                                $top_docs = $value;
+                            }
                         }
                         if(exists $agg->{by} ) {
                             my $by = delete $agg->{by};
@@ -437,7 +444,9 @@ AGES: while( !$DONE && @AGES ) {
                                         foreach my $dk (qw(score doc_count bg_count)) {
                                             next unless exists $subagg->{$dk};
                                             my $v = delete $subagg->{$dk};
-                                            push @elms, defined $v ? ($dk eq 'score' ? sprintf "%0.3f", $v : $v ) : '-';
+                                            push @elms, defined $v ? ($dk eq 'score' ? sprintf $CONFIG{decimal_format}, $v : $v ) : '-';
+                                            push @elms, sprintf $CONFIG{decimal_format}, $v / $top_docs
+                                                if $dk eq 'doc_count' and $top_docs;
                                         }
                                         push @sub, \@elms;
                                     }
@@ -461,7 +470,7 @@ AGES: while( !$DONE && @AGES ) {
                                     my %alias = qw( variance var std_deviation stdev );
                                     foreach my $stat (qw(count min avg max sum variance std_deviation)) {
                                         next unless exists $agg->{$k}{$stat};
-                                        my $v = $agg->{$k}{$stat} =~ /\./ ? sprintf "%0.3f", $agg->{$k}{$stat}
+                                        my $v = $agg->{$k}{$stat} =~ /\./ ? sprintf $CONFIG{decimal_format}, $agg->{$k}{$stat}
                                                                           : $agg->{$k}{$stat};
                                         push @stats, $alias{$stat} || $stat => $v;
                                     }
@@ -597,7 +606,9 @@ if($CONFIG{summary} && keys %AGGS_TOTALS) {
         output({color=>'cyan'},$agg_header);
     }
     foreach my $k (sort { $AGGS_TOTALS{$b} <=> $AGGS_TOTALS{$a} } keys %AGGS_TOTALS) {
-        output({data=>1,color=>'green'},"$AGGS_TOTALS{$k}\t$k");
+        output({data=>1,color=>'green'}, join "\t",
+                $AGGS_TOTALS{$k}, sprintf($CONFIG{decimal_format}, $AGGS_TOTALS{$k} / $TOTAL_HITS), $k
+        );
     }
 }
 
@@ -710,7 +721,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 7.7
+version 7.8
 
 =head1 SYNOPSIS
 
@@ -733,6 +744,7 @@ Options:
     --exists            Field which must be present in the document
     --missing           Field which must not be present in the document
     --size              Result size, default is 20, aliased to -n and --limit
+    --max-batch-size    When making requests to ES, retrieve this many docs in a single request, defaults to 50
     --all               Don't consider result size, just give me *everything*
     --asc               Sort by ascending timestamp
     --desc              Sort by descending timestamp (Default)
@@ -740,6 +752,7 @@ Options:
     --format            When --show isn't used, use this method for outputting the record, supported: json, jsonpretty, yaml
                         json assumes --no-decorator as we assume you're piping through jq
     --pretty            Where possible, use JSON->pretty
+    --precision         For floating point values, use this many digits of precision, defaults to 3
     --no-decorators     Do not show the header with field names in the query results
     --no-header         Same as above
     --no-implications   Don't attempt to imply filters from statistical aggregations
@@ -855,6 +868,10 @@ Output format to use when the full record is dumped.  The default is 'yaml', but
 
     --format json
 
+=item B<precision>
+
+For output involving floating point numbers, use this many places to the right of the decimal point.  The default is 3.
+
 =item B<tail>
 
 Repeats the query every second until CTRL+C is hit, displaying new results.  Due to the implementation,
@@ -915,18 +932,18 @@ distinct host) of hosts showing the top 5 hosts
 
 Without the --with, the results might look like this:
 
-    112314 sshd
-    21224  ntp
+    112314 0.151 sshd
+    21224  0.151 ntp
 
 The B<--with> option would expand that output to look like this:
 
-    112314   host   bastion-804   12431   sshd
-    112314   host   bastion-803   10009   sshd
-    112314   host   bastion-805   9768    sshd
-    112314   host   bastion-801   8789    sshd
-    112314   host   bastion-802   4121    sshd
-    21224    host   webapp-324    21223   ntp
-    21224    host   mail-42       1       ntp
+    112314   0.151 host   bastion-804   12431  0.111 sshd
+    112314   0.151 host   bastion-803   10009  0.089 sshd
+    112314   0.151 host   bastion-805   9768   0.087 sshd
+    112314   0.151 host   bastion-801   8789   0.078 sshd
+    112314   0.151 host   bastion-802   4121   0.037 sshd
+    21224    0.016 host   webapp-324    21223  0.999 ntp
+    21224    0.016 host   mail-42       1      0.000 ntp
 
 This may be specified multiple times, the result is more I<rows>, not more I<columns>, e.g.
 
@@ -934,16 +951,16 @@ This may be specified multiple times, the result is more I<rows>, not more I<col
 
 Produces:
 
-    112314   dc     arlington     112314  sshd
-    112314   host   bastion-804   12431   sshd
-    112314   host   bastion-803   10009   sshd
-    112314   host   bastion-805   9768    sshd
-    112314   host   bastion-801   8789    sshd
-    112314   host   bastion-802   4121    sshd
-    21224    dc     amsterdam     21223   ntp
-    21224    dc     la            1       ntp
-    21224    host   webapp-324    21223   ntp
-    21224    host   mail-42       1       ntp
+    112314 0.151  dc     arlington     112314 1.000 sshd
+    112314 0.151  host   bastion-804   12431  0.111 sshd
+    112314 0.151  host   bastion-803   10009  0.089 sshd
+    112314 0.151  host   bastion-805   9768   0.087 sshd
+    112314 0.151  host   bastion-801   8789   0.078 sshd
+    112314 0.151  host   bastion-802   4121   0.037 sshd
+    21224  0.016  dc     amsterdam     21223  0.999 ntp
+    21224  0.016  dc     la            1      0.000 ntp
+    21224  0.016  host   webapp-324    21223  0.999 ntp
+    21224  0.016  host   mail-42       1      0.000 ntp
 
 You may sub aggregate using any L<bucket agggregation|https://www.elastic.co/guide/en/elasticsearch/reference/master/search-aggregations-bucket.html>
 as long as the aggregation provides a B<key> element.  Additionally, doc_count, score, and bg_count will be reported in the output.
